# Scratchpad

TODO!

## JSON Pointer

###### `<tao/json/contrib/get.hpp>`

###### `<tao/json/contrib/patch.hpp>`

###### `<tao/json/contrib/refefence.hpp>`

###### `<tao/json/contrib/schema.hpp>`

## Still Need Description

* `events::apply`
* `events::basic_compare`
* `events::compare`
* `events::transformer`
* `nlohmann::from_value`
* `nlohmann::to_value`
* TODO: Anything missing?

Copyright (c) 2018-2022 Dr. Colin Hirsch and Daniel Frey
